"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

require("carbon-components/scss/components/link/_link.scss");

var _iconsReact = require("@carbon/icons-react");

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@cypress/react");

var _Link = _interopRequireDefault(require("../Link"));

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
describe('Link', function () {
  beforeEach(function () {
    (0, _react2.mount)( /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Link.default, {
      href: "http://www.carbondesignsystem.com"
    }, "Link"), /*#__PURE__*/_react.default.createElement(_Link.default, {
      href: "http://www.carbondesignsystem.com",
      renderIcon: _iconsReact.Download16
    }, "Download")));
  });
  it('should render', function () {
    cy.findByText(/Link/).should('be.visible'); // snapshots should always be taken _after_ an assertion that
    // a element/component should be visible. This is to ensure
    // the DOM has settled and the element has fully loaded.

    cy.percySnapshot();
  });
});